@@ -1,7 +1,7 @@
 """Console script for addthalesnumbers."""
 import argparse
 import sys
-
+import addthalesnumbers as atn
 
 def main():
     """Console script for addthalesnumbers."""
@@ -10,9 +10,7 @@ def main():
     args = parser.parse_args()
 
     print("Arguments: " + str(args._))
-    print("Replace this message by putting your code into "
-          "addthalesnumbers.cli.main")
-    return 0
+    return atn.addthalesnumbers.addnumbers(args)
 
 
 if __name__ == "__main__":
